@@ -1,9 +1,8 @@
 __title__ = "qiipy"
 __anthor__ = "peco2282"
 __license__ = "MIT"
-__version__ = "1.0.0"
+__version__ = "1.1.0"
 
-from .client import *
 from .comment import *
 from .exception import *
 from .group import *
@@ -12,9 +11,10 @@ from .item import *
 from .member import *
 from .project import *
 from .reaction import *
-from .route import *
+from .session import *
 from .tag import *
 from .tagging import *
 from .team import *
 from .team_member import *
 from .template import *
+from .client import *
