@@ -1,10 +1,10 @@
 from enum import Enum
-from typing import List
+from typing import List, Optional
 
 from . import Group, GroupMember, Comment, Tagging, Team, TeamMember, Template, Project
 from .exception import InvalidItemsRequested
 from .item import Item
-from .route import Route
+from .session import Session
 from .tag import Tag
 from .user import User
 
@@ -32,7 +32,7 @@ class Client:
                 "Too many items were requested. You can request more than 1 and less than 100."
             )
 
-        response = Route(
+        response = Session(
             method="GET",
             token=self.token,
             path=f"groups?page={page}&per_page={items}"
@@ -40,7 +40,7 @@ class Client:
         return [Group(group) for group in response.response.json()]
 
     def get_group(self, url_name: str) -> Group:
-        response = Route(
+        response = Session(
             method="GET",
             token=self.token,
             path=f"groups/{url_name}"
@@ -54,7 +54,7 @@ class Client:
         pass
 
     def delete_group(self, url_name: str) -> None:
-        response = Route(
+        response = Session(
             method="DELETE",
             token=self.token,
             path=f"groups/{url_name}"
@@ -73,7 +73,7 @@ class Client:
             raise InvalidItemsRequested(
                 "Too many items were requested. You can request more than 1 and less than 100."
             )
-        response = Route(
+        response = Session(
             method="GET",
             token=self.token,
             path=f"groups/{url_name}/members?page={page}&per_page={items}"
@@ -85,7 +85,7 @@ class Client:
             url_name: str,
             user_id: str
     ) -> GroupMember:
-        response = Route(
+        response = Session(
             method="GET",
             token=self.token,
             path=f"groups/{url_name}/members/{user_id}"
@@ -108,7 +108,7 @@ class Client:
         else:
             raise ValueError()
 
-        response = Route(
+        response = Session(
             method="POST",
             token=self.token,
             path=f"groups/{url_name}/members",
@@ -131,7 +131,7 @@ class Client:
         else:
             raise ValueError()
 
-        response = Route(
+        response = Session(
             method="DELETE",
             token=self.token,
             path=f"groups/{url_name}/members",
@@ -143,7 +143,7 @@ class Client:
             self,
             comment_id: str
     ) -> bool:
-        response = Route(
+        response = Session(
             method="DELETE",
             token=self.token,
             path=f"comments/{comment_id}"
@@ -156,8 +156,8 @@ class Client:
     def get_comment(
             self,
             comment_id: str
-    ) -> Comment:
-        response = Route(
+    ) -> Optional[Comment]:
+        response = Session(
             method="GET",
             token=self.token,
             path=f"comments/{comment_id}"
@@ -169,8 +169,8 @@ class Client:
     def get_comments(
             self,
             item_id: str
-    ) -> List[Comment]:
-        response = Route(
+    ) -> Optional[List[Comment]]:
+        response = Session(
             method="GET",
             token=self.token,
             path=f"items/{item_id}/comments"
@@ -183,8 +183,8 @@ class Client:
             self,
             item_id: str,
             comment: str
-    ) -> Comment:
-        response = Route(
+    ) -> Optional[Comment]:
+        response = Session(
             method="POST",
             token=self.token,
             path=f"items/{item_id}/comments"
@@ -198,8 +198,8 @@ class Client:
     def get_project_comments(
             self,
             project_id: str
-    ) -> Comment:
-        response = Route(
+    ) -> Optional[Comment]:
+        response = Session(
             method="GET",
             token=self.token,
             path=f"projects/{project_id}/comments"
@@ -212,8 +212,8 @@ class Client:
             self,
             project_id: str,
             comment: str
-    ) -> Comment:
-        response = Route(
+    ) -> Optional[Comment]:
+        response = Session(
             method="POST",
             token=self.token,
             path=f"projects/{project_id}",
@@ -228,8 +228,8 @@ class Client:
             project_id: str,
             comment: str,
             user_id: str
-    ) -> Comment:
-        response = Route(
+    ) -> Optional[Comment]:
+        response = Session(
             method="POST",
             token=self.token,
             path=f"projects/{project_id}/imported_comments",
@@ -243,8 +243,8 @@ class Client:
             self,
             comment_id: str,
             comment: str
-    ) -> Comment:
-        response = Route(
+    ) -> Optional[Comment]:
+        response = Session(
             method="PATCH",
             token=self.token,
             path=f"comments/{comment_id}",
@@ -260,12 +260,12 @@ class Client:
             item_id: str,
             tag_name: str,
             versions: List[str] = None
-    ) -> Tagging:
+    ) -> Optional[Tagging]:
         json = dict()
         json["name"] = tag_name
         if versions:
             json["versions"] = versions
-        response = Route(
+        response = Session(
             method="POST",
             token=self.token,
             path=f"items/{item_id}/tagging",
@@ -279,8 +279,8 @@ class Client:
             self,
             item_id: str,
             tagging_id: str
-    ):
-        response = Route(
+    ) -> bool:
+        response = Session(
             method="DELETE",
             token=self.token,
             path=f"items/{item_id}/tagging/{tagging_id}"
@@ -293,8 +293,8 @@ class Client:
     def get_tag(
             self,
             tag_id: str
-    ) -> Tag:
-        response = Route(
+    ) -> Optional[Tag]:
+        response = Session(
             method="GET",
             token=self.token,
             path=f"tags/{tag_id}"
@@ -303,28 +303,30 @@ class Client:
             return Tag(response.response.json())
         return None
 
-    def get_tags(self, sort: Sort, page: int = 1, items: int = 20) -> List[Tag]:
+    def get_tags(self, sort: Sort, page: int = 1, items: int = 20) -> Optional[List[Tag]]:
         if items > 100 | items <= 0:
             raise InvalidItemsRequested("Too many items were requested. You can request more than 1 and less than 100.")
-
-        response = Route(
+        sort = sort.value
+        response = Session(
             method="GET",
             token=self.token,
             path=f"tags?page={page}&per_page={items}"
         )
-        return [Tag(data) for data in response.response.json()]
+        if response.response.status_code == 204:
+            return [Tag(data) for data in response.response.json()]
+        return None
 
     def get_following_tags(
             self,
             user_id: str,
             page: int = 1,
             items: int = 20
-    ) -> List[Tag]:
+    ) -> Optional[List[Tag]]:
         if items > 100 | items <= 0:
             raise InvalidItemsRequested(
                 "Too many items were requested. You can request more than 1 and less than 100."
             )
-        response = Route(
+        response = Session(
             method="GET",
             token=self.token,
             path=f"users/{user_id}/following_tags?page={page}&per_page={items}"
@@ -336,8 +338,8 @@ class Client:
     def delete_following_tag(
             self,
             tag_id: str
-    ):
-        response = Route(
+    ) -> bool:
+        response = Session(
             method="DELETE",
             token=self.token,
             path=f"tags/{tag_id}/following"
@@ -349,8 +351,8 @@ class Client:
     def follow_tag(
             self,
             tag_id: str
-    ):
-        response = Route(
+    ) -> bool:
+        response = Session(
             method="PUT",
             token=self.token,
             path=f"tags/{tag_id}/following"
@@ -360,8 +362,8 @@ class Client:
         return False
 
     # チーム
-    def get_user_teams(self) -> List[Team]:
-        response = Route(
+    def get_user_teams(self) -> Optional[List[Team]]:
+        response = Session(
             method="GET",
             token=self.token,
             path=f"teams"
@@ -375,12 +377,12 @@ class Client:
             self,
             items: int = 1,
             page: int = 20
-    ) -> List[TeamMember]:
+    ) -> Optional[List[TeamMember]]:
         if items > 100 | items <= 0:
             raise InvalidItemsRequested(
                 "Too many items were requested. You can request more than 1 and less than 100."
             )
-        response = Route(
+        response = Session(
             method="GET",
             token=self.token,
             path=f"team_memberships?page={items}&per_page={page}"
@@ -394,12 +396,12 @@ class Client:
             self,
             page: int = 1,
             items: int = 20
-    ) -> List[Template]:
+    ) -> Optional[List[Template]]:
         if items > 100 | items <= 0:
             raise InvalidItemsRequested(
                 "Too many items were requested. You can request more than 1 and less than 100."
             )
-        response = Route(
+        response = Session(
             method="GET",
             token=self.token,
             path=f"templates?page={page}&per_page={items}"
@@ -412,7 +414,7 @@ class Client:
             self,
             template_id: str
     ):
-        response = Route(
+        response = Session(
             method="DELETE",
             token=self.token,
             path=f"templates/{template_id}"
@@ -424,8 +426,8 @@ class Client:
     def get_template(
             self,
             template_id: str
-    ) -> Template:
-        response = Route(
+    ) -> Optional[Template]:
+        response = Session(
             method="GET",
             token=self.token,
             path=f"templates/{template_id}"
@@ -442,12 +444,12 @@ class Client:
             self,
             page: int = 1,
             items: int = 20
-    ) -> List[Project]:
+    ) -> Optional[List[Project]]:
         if items > 100 | items <= 0:
             raise InvalidItemsRequested(
                 "Too many items were requested. You can request more than 1 and less than 100."
             )
-        response = Route(
+        response = Session(
             method="GET",
             token=self.token,
             path=f"projects?page={page}&per_page={items}"
@@ -463,8 +465,8 @@ class Client:
     def get_project(
             self,
             project_id: str
-    ):
-        response = Route(
+    ) -> Optional[Project]:
+        response = Session(
             method="GET",
             token=self.token,
             path=f"projects/{project_id}"
@@ -477,7 +479,7 @@ class Client:
 
     # ユーザー
     def get_authenticated_user_data(self) -> User:
-        response = Route(
+        response = Session(
             method="GET",
             token=self.token,
             path="authenticated_user"
@@ -489,13 +491,13 @@ class Client:
             item_id: str,
             page: int = 1,
             items: int = 20
-    ) -> List[Item]:
+    ) -> Optional[List[Item]]:
         if items > 100 | items <= 0:
             raise InvalidItemsRequested(
                 "Too many items were requested. You can request more than 1 and less than 100."
             )
 
-        response = Route(
+        response = Session(
             method="GET",
             token=self.token,
             path=f"items/{item_id}/stockers?page={page}&per_page={items}"
@@ -507,8 +509,8 @@ class Client:
     def get_user(
             self,
             user_id: str
-    ) -> User:
-        response = Route(
+    ) -> Optional[User]:
+        response = Session(
             method="GET",
             token=self.token,
             path=f"users/{user_id}"
@@ -521,13 +523,13 @@ class Client:
             self,
             page: int = 1,
             items: int = 20
-    ) -> List[User]:
+    ) -> Optional[List[User]]:
         if items > 100 | items <= 0:
             raise InvalidItemsRequested(
                 "Too many items were requested. You can request more than 1 and less than 100."
             )
 
-        response = Route(
+        response = Session(
             method="",
             token=self.token,
             path=f"users?page={page}&per_page={items}"
@@ -541,13 +543,13 @@ class Client:
             user_id: str,
             page: int = 1,
             items: int = 20
-    ) -> List[User]:
+    ) -> Optional[List[User]]:
         if items > 100 | items <= 0:
             raise InvalidItemsRequested(
                 "Too many items were requested. You can request more than 1 and less than 100."
             )
 
-        response = Route(
+        response = Session(
             method="GET",
             token=self.token,
             path=f"users/{user_id}/followees?page={page}&per_page={items}"
@@ -561,13 +563,13 @@ class Client:
             user_id: str,
             page: int = 1,
             items: int = 20
-    ) -> List[User]:
+    ) -> Optional[List[User]]:
         if items > 100 | items <= 0:
             raise InvalidItemsRequested(
                 "Too many items were requested. You can request more than 1 and less than 100."
             )
 
-        response = Route(
+        response = Session(
             method="GET",
             token=self.token,
             path=f"users/{user_id}/followers?page={page}&per_page={items}"
@@ -580,7 +582,7 @@ class Client:
             self,
             user_id: str
     ) -> bool:
-        response = Route(
+        response = Session(
             method="DELETE",
             token=self.token,
             path=f"users/{user_id}/following"
@@ -593,7 +595,7 @@ class Client:
             self,
             user_id: str
     ) -> bool:
-        response = Route(
+        response = Session(
             method="GET",
             token=self.token,
             path=f"users/{user_id}/following"
@@ -606,7 +608,7 @@ class Client:
             self,
             user_id: str
     ) -> bool:
-        response = Route(
+        response = Session(
             method="PUT",
             token=self.token,
             path=f"users/{user_id}/following"
@@ -620,7 +622,7 @@ class Client:
             self,
             item_id: str
     ) -> Item:
-        response = Route(
+        response = Session(
             "GET",
             token=self.token,
             path=f"items/{item_id}"
@@ -639,7 +641,7 @@ class Client:
                 "Too many items were requested. You can request more than 1 and less than 100."
             )
 
-        response = Route(
+        response = Session(
             method="GET",
             token=self.token,
             path=f"authenticated_user/items?page={page}&per_page={items}"
@@ -652,7 +654,7 @@ class Client:
             self,
             item_id: str
     ) -> bool:
-        response = Route(
+        response = Session(
             method="DELETE",
             token=self.token,
             path=f"items/{item_id}"
@@ -665,7 +667,7 @@ class Client:
             self,
             item_id: str
     ) -> bool:
-        response = Route(
+        response = Session(
             method="GET",
             token=self.token,
             path=f"items/{item_id}/stock"
@@ -676,12 +678,12 @@ class Client:
 
     def set_stock(
             self,
-            itme_id: str
+            item_id: str
     ) -> bool:
-        response = Route(
+        response = Session(
             method="PUT",
             token=self.token,
-            path=f"items/{itme_id}/stock"
+            path=f"items/{item_id}/stock"
         )
         if response.response.status_code == 204:
             return True
@@ -692,10 +694,10 @@ class Client:
             tag_id: str,
             page: int = 1,
             items: int = 20
-    ) -> List[Item]:
+    ) -> Optional[List[Item]]:
         if items > 100 | items <= 0:
             raise InvalidItemsRequested("Too many items were requested. You can request more than 1 and less than 100.")
-        response = Route(
+        response = Session(
             method="GET",
             token=self.token,
             path=f"tags/{tag_id}/items?page={page}&per_page={items}"
